@@ -48,22 +48,14 @@ mark_time("Python imports done")
 if '--debug' in sys.argv:
     os.environ['G_ENABLE_DIAGNOSTIC'] = '1'
 
-HERE = os.path.dirname(__file__)
 
-SCHEMA_DIR = os.path.join(HERE, 'data')
-if SCHEMA_DIR and not os.environ.get('GSETTINGS_SCHEMA_DIR'):
-    # Have to do this before importing 'gi'.
-    os.environ['GSETTINGS_SCHEMA_DIR'] = SCHEMA_DIR
-    if not os.path.exists(os.path.join(SCHEMA_DIR, 'gschemas.compiled')):
-        # This, too, I have to do before importing 'gi'.
-        print("Compiling GSettings schema")
-        glib_compile_schemas = os.path.join(sys.prefix, 'lib', 'site-packages', 'gnome', 'glib-compile-schemas.exe')
-        if not os.path.exists(glib_compile_schemas):
-            glib_compile_schemas = 'glib-compile-schemas'
-        try:
-            subprocess.call([glib_compile_schemas, SCHEMA_DIR])
-        except OSError as e:
-            print("Failed: %s" % e)
+# The gtimelog.paths import has important side effects and must be done before
+# importing 'gi'.
+
+from .paths import (
+    UI_FILE, PREFERENCES_UI_FILE, ABOUT_DIALOG_UI_FILE, SHORTCUTS_UI_FILE,
+    MENUS_UI_FILE, CSS_FILE, LOCALE_DIR, CONTRIBUTORS_FILE,
+)
 
 
 import gi
@@ -95,23 +87,6 @@ else:
 
 mark_time("gtimelog imports done")
 
-UI_DIR = HERE
-
-if (Gtk.MAJOR_VERSION, Gtk.MINOR_VERSION) < (3, 12):
-    UI_FILE = os.path.join(UI_DIR, 'gtimelog-gtk3.10.ui')
-    PREFERENCES_UI_FILE = os.path.join(UI_DIR, 'preferences-gtk3.10.ui')
-else:
-    UI_FILE = os.path.join(UI_DIR, 'gtimelog.ui')
-    PREFERENCES_UI_FILE = os.path.join(UI_DIR, 'preferences.ui')
-
-ABOUT_DIALOG_UI_FILE = os.path.join(UI_DIR, 'about.ui')
-SHORTCUTS_UI_FILE = os.path.join(UI_DIR, 'shortcuts.ui')
-MENUS_UI_FILE = os.path.join(UI_DIR, 'menus.ui')
-CSS_FILE = os.path.join(UI_DIR, 'gtimelog.css')
-LOCALE_DIR = os.path.join(UI_DIR, 'locale')
-
-CONTRIBUTORS_FILE = os.path.join(UI_DIR, 'CONTRIBUTORS.rst')
-
 
 log = logging.getLogger('gtimelog')
 
@@ -448,11 +423,17 @@ class Application(Gtk.Application):
     def on_quit(self, action, parameter):
         self.quit()
 
+    def open_in_editor(self, filename):
+        self.create_if_missing(filename)
+        if os.name == 'nt':
+            os.startfile(filename)
+        else:
+            uri = GLib.filename_to_uri(filename, None)
+            Gtk.show_uri(None, uri, Gdk.CURRENT_TIME)
+
     def on_edit_log(self, action, parameter):
         filename = Settings().get_timelog_file()
-        uri = GLib.filename_to_uri(filename, None)
-        self.create_if_missing(filename)
-        Gtk.show_uri(None, uri, Gdk.CURRENT_TIME)
+        self.open_in_editor(filename)
 
     def on_edit_tasks(self, action, parameter):
         gsettings = Gio.Settings.new("org.gtimelog")
@@ -460,11 +441,10 @@ class Application(Gtk.Application):
             uri = gsettings.get_string('task-list-edit-url')
             if self.get_active_window() is not None:
                 self.get_active_window().editing_remote_tasks = True
+            Gtk.show_uri(None, uri, Gdk.CURRENT_TIME)
         else:
             filename = Settings().get_task_list_file()
-            self.create_if_missing(filename)
-            uri = GLib.filename_to_uri(filename, None)
-        Gtk.show_uri(None, uri, Gdk.CURRENT_TIME)
+            self.open_in_editor(filename)
 
     def on_refresh_tasks(self, action, parameter):
         gsettings = Gio.Settings.new("org.gtimelog")
@@ -515,16 +495,9 @@ class Application(Gtk.Application):
         mark_time("in app activate")
         window = self.get_active_window()
         if window is not None:
-            if not window.is_active() and not self.are_there_any_modals():
-                # If I don't hide the window before calling present(), GNOME
-                # Shell (on Wayland) ignores the presentation request:
-                # https://bugzilla.gnome.org/show_bug.cgi?id=756202 and
-                # https://bugzilla.gnome.org/show_bug.cgi?id=766284
-                # If I do hide the window, present() works, but -- again, under
-                # Wayland -- forgets the window position and jumps to the
-                # top-left corner of the 1st screen :(
-                window.hide()
-            window.present()
+            # window.present() doesn't work on wayland:
+            # https://gitlab.gnome.org/GNOME/gtk/issues/624#note_119092
+            window.present_with_time(GLib.get_monotonic_time() // 1000)
             return
 
         window = Window(self)
@@ -1035,7 +1008,7 @@ class Window(Gtk.ApplicationWindow):
             self.gsettings.set_int('task-pane-position', tpp)
 
     def store_window_size(self):
-        if not self.is_maximized_in_any_way():
+        if self.props.window is not None and not self.is_maximized_in_any_way():
             self._store_window_size()
         GLib.source_remove(self._window_size_update_timeout)
         self._window_size_update_timeout = None
@@ -1655,11 +1628,14 @@ class LogView(Gtk.TextView):
                 self.wfmt(_('Total for {0}: {1} ({2} per day)'), *args)
             else:
                 weekly_window = self.timelog.window_for_week(self.date)
+                work_days_in_week = weekly_window.count_days() or 1
                 week_work, week_slacking = weekly_window.totals(
                     filter_text=self.filter_text)
                 week_total = week_work + week_slacking
                 args.append((format_duration(week_total), 'duration'))
-                self.wfmt(_('Total for {0}: {1} ({2} this week)'), *args)
+                per_diem = week_total / work_days_in_week
+                args.append((format_duration(per_diem), 'duration'))
+                self.wfmt(_('Total for {0}: {1} ({2} this week, {3} per day)'), *args)
             self.w('\n')
         self.reposition_cursor()
         self.add_footer()
